==> haskell-microlens-platform-0.4.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-platform
version:              0.4.1
visibility:           public
id:                   microlens-platform-0.4.1-Dz72fjBzWaCG34jFwnfBb7
key:                  microlens-platform-0.4.1-Dz72fjBzWaCG34jFwnfBb7
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  efb1e4532173d6b235c99f222030baa2
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/microlens-platform-0.4.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/microlens-platform-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/microlens-platform-0.4.1
hs-libraries:         HSmicrolens-platform-0.4.1-Dz72fjBzWaCG34jFwnfBb7
depends:
    base-4.14.1.0 hashable-1.3.0.0-JGLlBEJENIuAu5I6ebR7jm
    microlens-0.4.11.2-9caS3Frz8K54yIHXMtlddL
    microlens-ghc-0.4.12-1AbATKxQMzZ7ILqBaxTA8l
    microlens-mtl-0.2.0.1-LdvXNIQNEV94YQezdBSAhZ
    microlens-th-0.4.3.5-25zRB3nNkx4IpSX6Cm7F3X text-1.2.3.2
    unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
    vector-0.12.1.2-1NVIFdUJ04d5LWJjqOrbRq

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.4.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-platform
version:              0.4.1
visibility:           public
id:                   microlens-platform-0.4.1-KmEy1c1fShJ9o9XDjx7VHk
key:                  microlens-platform-0.4.1-KmEy1c1fShJ9o9XDjx7VHk
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  f22edd02ff9805a37130c1a652ff4c8e
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/microlens-platform-0.4.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/microlens-platform-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/microlens-platform-0.4.1
hs-libraries:         HSmicrolens-platform-0.4.1-KmEy1c1fShJ9o9XDjx7VHk
depends:
    base-4.14.1.0 hashable-1.3.0.0-JdGAj1lGWBF8rPo7OULhuw
    microlens-0.4.11.2-9caS3Frz8K54yIHXMtlddL
    microlens-ghc-0.4.12-1AbATKxQMzZ7ILqBaxTA8l
    microlens-mtl-0.2.0.1-LdvXNIQNEV94YQezdBSAhZ
    microlens-th-0.4.3.5-25zRB3nNkx4IpSX6Cm7F3X text-1.2.3.2
    unordered-containers-0.2.12.0-JMHeBencosjFi5kYThmmhW
    vector-0.12.1.2-Ey11gGB2S4fIXSHQgTBQEm

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
